@@ -1,4 +1,3 @@
-# $Id: MapGen.pm,v 1.61 2006/08/30 18:22:44 jettero Exp $
 # vi:tw=0 syntax=perl:
 
 package Games::RolePlay::MapGen;
@@ -8,7 +7,7 @@ use AutoLoader;
 use Carp;
 use Data::Dumper; $Data::Dumper::Indent = 1; $Data::Dumper::SortKeys = 1;
 
-our $VERSION = "0.29";
+our $VERSION = "1.0.1";
 our $AUTOLOAD;
 
 our %opp = (n=>"s", e=>"w", s=>"n", w=>"e");
@@ -91,6 +90,9 @@ sub AUTOLOAD {
     my $this = shift;
     my $sub  = $AUTOLOAD;
 
+    # sub set_generator
+    # sub set_exporter
+
     if( $sub =~ m/MapGen\:\:set_(generator|exporter)$/ ) {
         my $type = $1;
         my $modu = shift;
@@ -156,10 +158,10 @@ sub save_map {
 
     my @keys = keys %$this;
 
-    open _SAVE, ">$filename" or die "couldn't open $filename for write: $!";
-    print _SAVE "#!/usr/bin/perl\n\n";
-    print _SAVE Data::Dumper->Dump([map($this->{$_}, @keys)], [map("\$this\-\>{$_}", @keys)]);
-    close _SAVE;
+    open my $save, ">$filename" or die "couldn't open $filename for write: $!";
+    print $save "#!/usr/bin/perl\n\n";
+    print $save Data::Dumper->Dump([map($this->{$_}, @keys)], [map("\$this\-\>{$_}", @keys)]);
+    close $save;
 
     $this->{_the_map}->interconnect_map;
 }
@@ -169,9 +171,10 @@ sub load_map {
     my $this     = shift;
     my $filename = shift;
 
-    open _LOAD, "$filename" or die "couldn't open $filename for read: $!";
-    my $entire_file = join("", <_LOAD>);
-    close _LOAD;
+    open my $load, "$filename" or die "couldn't open $filename for read: $!";
+    local $/ = undef;
+    my $entire_file = <$load>;
+    close $load;
 
     eval $entire_file;
     die "ERROR while evaluating saved map: $@" if $@;
@@ -233,9 +236,7 @@ sub export {
     __MADE_VIS_OBJ:
     if( my $vis = $this->{objs}{exporter} ) {
 
-        $vis->go( _the_map => $this->{_the_map}, _the_groups => $this->{_the_groups}, (@_==1 ? (fname=>$_[0]) : @_) );
-
-        return;
+        return $vis->go( _the_map => $this->{_the_map}, _the_groups => $this->{_the_groups}, (@_==1 ? (fname=>$_[0]) : @_) );
 
     } else {
         die "problem creating new exporter object" if $err;
@@ -262,6 +263,32 @@ sub export {
 }
 # }}}
 
+# import_xml {{{
+sub import_xml {
+    my $this = shift;
+    my $that = shift; croak "no such file that=$that" unless -f $that;
+
+    $this = $this->new unless ref $this;
+
+    $this->set_generator( "XMLImport" );
+    $this->generate( xml_input_file => $that ); 
+
+    $this;
+}
+# }}}
+# size {{{
+sub size {
+    my $this = shift;
+    my $map  = $this->{_the_map};
+
+    my $x = @{$map->[0]};
+    my $y = @$map;
+
+    return ($x, $y) if wantarray;
+    return [$x, $y];
+}
+# }}}
+
 __END__
 # Below is stub documentation for your module. You better edit it!
 
