@@ -1,4 +1,3 @@
-# $Id: Basic.pm,v 1.35 2005/04/02 17:26:17 jettero Exp $
 # vi:tw=0 syntax=perl:
 
 package Games::RolePlay::MapGen::Generator::Basic;
@@ -318,6 +317,11 @@ sub cleanup_pseudo_rooms {
             }
         }
     }
+
+    for my $tile (grep {$_->{group}} map {@$_} @$map) {
+        delete $tile->{group}
+            if $tile->{group}{type} eq "pseudo";
+    }
 }
 # }}}
 
